==> deepin-camera_6.5.5.tar.xz: BUILD/src/translations/deepin-camera_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Die Videoaufnahme läuft. Das Fenster schließen?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Ordner öffnen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Kameras wechseln</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ordner öffnen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Du hast keine Berechtigung, diesen Ordner zu verwenden</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Ungültiger Ordner</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ordner öffnen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Grundlegend</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Dateispeicherort</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Fotografieren</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Serienbildmodus</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Selbstauslöser-Verzögerung</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Ausgabe</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Ausgabeformat</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 Stk.</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 Stk.</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera ist ein Dienstprogramm zur Bild- und Videoaufnahme, das Ihre PC-Kamera oder Webcam verwendet.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Datei nicht gespeichert</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Speichern unter:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Auflösungseinstellungen</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Auflösung:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Klangeffekte</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Spiegelmodus</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Blitzlicht</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Aufnahme stoppen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tastaturkürzel anzeigen</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Keine Fotos mehr machen</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontextmenü</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Foto machen</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Video aufnehmen</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Keine Fotos mehr machen</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Lebendig</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Warm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Kalt</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grau</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>SW</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Blitzlicht</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ein</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Aus</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Aufnahme verzögern</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Belichtung</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Keine Webkamera gefunden</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Die Webkamera ist in Betrieb</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Aufnahme stoppen</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Die Videoaufnahme läuft. Das Fenster schließen?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Ordner öffnen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Kameras wechseln</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ordner öffnen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Du hast keine Berechtigung, diesen Ordner zu verwenden</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Ungültiger Ordner</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ordner öffnen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Grundlegend</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Dateispeicherort</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Fotografieren</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Serienbildmodus</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Selbstauslöser-Verzögerung</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Ausgabe</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Ausgabeformat</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 Stk.</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 Stk.</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera ist ein Dienstprogramm zur Bild- und Videoaufnahme, das Ihre PC-Kamera oder Webcam verwendet.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Datei nicht gespeichert</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Speichern unter:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Auflösungseinstellungen</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Auflösung:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Klangeffekte</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Spiegelmodus</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Blitzlicht</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Gitternetzlinien</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 Linien</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 Linien</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Maximale Auflösung:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Aufnahme stoppen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tastaturkürzel anzeigen</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Keine Fotos mehr machen</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontextmenü</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Foto machen</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Video aufnehmen</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Keine Fotos mehr machen</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Lebendig</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Warm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Kalt</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grau</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>SW</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Blitzlicht</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ein</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Aus</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Aufnahme verzögern</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Belichtung</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Keine Webkamera gefunden</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Die Webkamera ist in Betrieb</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Aufnahme stoppen</translation>
    </message>
</context>
</TS>
